pub struct UploadDecisionRequest {
pub tradeoff: TradeoffReceipt,
pub scenario: Option<ScenarioReceipt>,
pub artifact_index: Option<DecisionArtifactIndex>,
pub git_ref: Option<String>,
pub git_sha: Option<String>,
}Expand description
Request for uploading a performance decision.
Fields
tradeoff: TradeoffReceiptscenario: Option<ScenarioReceipt>artifact_index: Option<DecisionArtifactIndex>git_ref: Option<String>git_sha: Option<String>Trait Implementations
Sourceimpl Clone for UploadDecisionRequest
impl Clone for UploadDecisionRequest
Sourcefn clone(&self) -> UploadDecisionRequest
fn clone(&self) -> UploadDecisionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UploadDecisionRequest
impl Debug for UploadDecisionRequest
Sourceimpl<'de> Deserialize<'de> for UploadDecisionRequest
impl<'de> Deserialize<'de> for UploadDecisionRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<UploadDecisionRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<UploadDecisionRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UploadDecisionRequest
impl JsonSchema for UploadDecisionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for UploadDecisionRequest
impl Serialize for UploadDecisionRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more